Converting masks back to annotations
======================================

.. automodule:: histomicstk.annotations_and_masks.masks_to_annotations_handler
    :members:
    :undoc-members:
    :show-inheritance:
